abacusai.news_search_result — AbacusAI documentation

# abacusai.news_search_result

## Classes

`NewsSearchResult` | A single news search result.

## Module Contents

class abacusai.news_search_result.NewsSearchResult(client, title=None, url=None, description=None, thumbnailUrl=None, thumbnailWidth=None, thumbnailHeight=None, faviconUrl=None, datePublished=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A single news search result.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - title (str) – The title of the news.

    - url (str) – The URL of the news.

    - description (str) – The description of the news.

    - thumbnailUrl (str) – The URL of the image of the news.

    - thumbnailWidth (int) – The width of the image of the news.

    - thumbnailHeight (int) – The height of the image of the news.

    - faviconUrl (str) – The URL of the favicon of the news.

    - datePublished (str) – The date the news was published.

  title = None
  url = None
  description = None
  thumbnail_url = None
  thumbnail_width = None
  thumbnail_height = None
  favicon_url = None
  date_published = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict